english_lowercase

Function english_lowercase 

pub fn english_lowercase() -> &'static HashMap<char, f64>
Returns the frequencies of each letter of the English alphabet as a map between characters and percentage of words they appear in. The returned map will include only lowercase characters. To get a different subset, use Frequency::english_uppercase() or Frequency::english() for both.

Performance

This is O(1).

Returns

A map of letters and their frequencies.